1
0
forked from pool/strongswan
strongswan/strongswan-4.x.x-getline.patch

43 lines
1.3 KiB
Diff

--- src/libfreeswan/optionsfrom.c
+++ src/libfreeswan/optionsfrom.c
@@ -31,7 +31,7 @@
static const char *dowork(const char *, int *, char ***, int);
static const char *getanarg(FILE *, struct work *, char **);
-static char *getline(FILE *, char *, size_t);
+static char *my_getline(FILE *, char *, size_t);
/*
- optionsfrom - add some options, taken from a file, to argc/argv
@@ -149,7 +149,7 @@
char *endp;
while (w->pending == NULL) { /* no pending line */
- if ((w->line = getline(f, w->buf, sizeof(w->buf))) == NULL)
+ if ((w->line = my_getline(f, w->buf, sizeof(w->buf))) == NULL)
return "error in line read"; /* caller checks EOF */
if (w->line[0] != '#' &&
*(w->line + strspn(w->line, " \t")) != '\0')
@@ -171,7 +171,7 @@
if (*linep == NULL)
return "out of memory for new line";
strcpy(*linep, p);
- } else /* getline already malloced it */
+ } else /* my_getline already malloced it */
*linep = p;
return NULL;
}
@@ -203,10 +203,10 @@
}
/*
- - getline - read a line from the file, trim newline off
+ - my_getline - read a line from the file, trim newline off
*/
static char * /* pointer to line, NULL for eof/error */
-getline(f, buf, bufsize)
+my_getline(f, buf, bufsize)
FILE *f;
char *buf; /* buffer to use, if convenient */
size_t bufsize; /* size of buf */